@@ -3,10 +3,9 @@
 
 #include "qnetworkreply.h"
 #include <QObject>
-#include <QStringList>
-#include <QMap>
-#include <QList>
-#include <QDomElement>
+#include <QWaitCondition>
+#include <QMutex>
+#include <QDomDocument>
 
 #include "remotedb.h"
 #include "remotedbmgr.h"
@@ -24,9 +23,19 @@ public slots: // public slots are not called by Qt Test framework
     void verifyDB(RemoteDB *db);
 
 private:
+    void createTestData();
+    void createTestDocument();
+    void createMfgElements(QChar &letter, QDomElement &parent);
+    void createModelElements(const QString &mfg, QDomElement &parent);
+    void verifyRemotes(RemoteDB *db);
+
+private:
+    QWaitCondition dbVerified;
+    QMutex dbMutex;
     RemoteDBMgr subject;
     RemoteDB validDB;
-    bool dbVerified;
+    bool dbOk;
+    QDomDocument document;
 
 };
 
